@@ -36,7 +36,7 @@ def pip(pkg, project_path, pname):
         subprocess.run(cmd, shell=True, executable=shell_path)
         os.chdir(project_path)
         print('\n🔰 Downloading packages...\n')
-        subprocess.check_call(pkgs)
+        subprocess.run(pkgs, check=True)
         return 1
     else:
         print("\nNo package downloaded...")
